@@ -271,7 +271,13 @@ sub bind_value {
         my $parent = join('.', @paths[0..$num-1]);
         my $abs = join('.', @paths[0..$num]);
 
-        next if $self->eval($abs);
+        if($self->eval($abs)) {
+            # We don't want to be able to rebind without unbinding first
+            croak "${name} already exists, unbind it first" if $num == $#paths;
+
+            next;
+        }
+        
         jsc_bind_value($self->{_impl}, $parent,
                        $paths[$num], $num == $#paths ? $object : {});
     }
@@ -279,6 +285,15 @@ sub bind_value {
     return;
 }
 
+sub unbind_value {
+    my ($self, $name, $object, $opt) = @_;
+
+    my @paths = split /\./, $name;
+    $name = pop @paths;
+    my $parent = join(".", @paths);
+    jsc_unbind_value($self->{_impl}, $parent, $name);
+}
+
 sub set_branch_handler {
     my ($self, $handler) = @_;
 
@@ -295,6 +310,17 @@ sub compile {
     return $script;
 }
 
+sub get_version {
+    my ($self, $version) = @_;
+    return jsc_get_version($self->{_impl});
+}
+
+sub set_version {
+    my ($self, $version) = @_;
+    jsc_set_version($self->{_impl}, $version);
+    1;
+}
+
 sub _destroy {
     my $self = shift;
     return unless $self->{'_impl'};
@@ -432,7 +458,11 @@ Binds a Perl object to the context under a given name.
 
 =item bind_value ( $name => $value )
 
-Defines a value with a given name and value.
+Defines a value with a given name and value. Trying to redefine an already existing property throws an exception.
+
+=item unbind_value ( $name )
+
+Removed a property from the context or a specified object.
 
 =item call ( $name, @arguments )
 
@@ -477,6 +507,19 @@ To remove the handler call this method with an undefined argument.
 
 The handler is called when a script branches backwards during execution, when a function returns and the end of the script. To continue execution the handler must return a true value. To abort execution either throw an exception or return a false value.
 
+=item get_version ( )
+
+Returns the runtime version of the context as a string, for exmaple C<1.7> or or C<ECMAv3>.
+
+=item set_version ( $version )
+
+Sets the runtime version of the context to that specified in the string I<$version>. Some features 
+such as C<let> and C<yield> might not be enabled by default and thus must be turned on by 
+specifying what JS version we're using.
+
+A list of these can be found at L<http://developer.mozilla.org/en/docs/JSVersion> but may vary 
+depending on the version of your runtime.
+
 =back
 
 =begin PRIVATE
@@ -529,10 +572,22 @@ Binds a function to the context.
 
 Defines a new named property in I<parent> with the value of I<object>.
 
+=item jsc_unbind_value ( PJS_Context *context, char *parent, char *name)
+
+Removes a new named property in I<parent>.
+
 =item jsc_set_branch_handler ( PJS_Context *context, SV *handler )
 
 Attaches a branch handler to the context. No check is made to see if I<handler> is a valid SVt_PVCV.
 
+=item jsc_get_version ( PJS_Context *context )
+
+Returns the version of the context as a string, for example "1.7"
+
+=item jsc_set_version ( PJS_Context *context, const char *version) 
+
+Set the version of the context to the one specified in version.
+
 =back
 
 =end PRIVATE
